============
Outlook Mail
============


.. image:: https://img.shields.io/pypi/v/outlookmail.svg
        :target: https://pypi.python.org/pypi/outlookmail

.. image:: https://img.shields.io/travis/luiggc[D[D[Dsggc/outlookmail.svg
        :target: https://travis-ci.com/luiggc[D[D[Dsggc/outlookmail

.. image:: https://readthedocs.org/projects/outlookmail/badge/?version=latest
        :target: https://outlookmail.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Make automatic many email related tasks in Outlook


* Free software: MIT license
* Documentation: https://outlookmail.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
